"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const context_1 = tslib_1.__importDefault(require("./context"));
const reducer_1 = tslib_1.__importStar(require("./reducer"));
const actions_1 = require("./actions");
const QuizQuestions_1 = tslib_1.__importDefault(require("../QuizQuestions"));
const ResultContainer_1 = tslib_1.__importDefault(require("../ResultContainer/ResultContainer"));
const constants_1 = require("../../constants");
const utils_1 = require("../../utils");
const Spinner_1 = tslib_1.__importDefault(require("../Spinner/Spinner"));
const useCioClient_1 = tslib_1.__importDefault(require("../../hooks/useCioClient"));
function CioQuiz(props) {
    const { quizId, apiKey, cioJsClient, resultsPageOptions, quizVersionId: quizVersionIdProp, } = props;
    if (!quizId) {
        // eslint-disable-next-line no-console
        console.error('quizId is a required field of type string');
    }
    if (!resultsPageOptions || Object.keys(resultsPageOptions).length === 0) {
        // eslint-disable-next-line no-console
        console.error('resultsPageOptions is a required field of type object');
    }
    if (resultsPageOptions && !(resultsPageOptions === null || resultsPageOptions === void 0 ? void 0 : resultsPageOptions.addToCartCallback)) {
        // eslint-disable-next-line no-console
        console.error('resultsPageOptions.addToCartCallback is a required field of type function');
    }
    const cioClient = (0, useCioClient_1.default)({ apiKey, cioJsClient });
    const [state, dispatch] = (0, react_1.useReducer)(reducer_1.default, reducer_1.initialState);
    const [requestState, setRequestState] = (0, react_1.useState)(constants_1.RequestStates.Stale);
    const [questionResponse, setQuestionResponse] = (0, react_1.useState)();
    const [resultsResponse, setResultsResponse] = (0, react_1.useState)();
    const [firstQuestion, setFirstQuestion] = (0, react_1.useState)();
    const [quizVersionId, setQuizVersionId] = (0, react_1.useState)(quizVersionIdProp || '');
    const [quizSessionId, setQuizSessionId] = (0, react_1.useState)('');
    const isFirstQuestion = (firstQuestion === null || firstQuestion === void 0 ? void 0 : firstQuestion.next_question.id) === (questionResponse === null || questionResponse === void 0 ? void 0 : questionResponse.next_question.id);
    const quizNextHandler = (0, react_1.useCallback)((action) => {
        if (action) {
            dispatch(action);
        }
    }, [dispatch]);
    const quizBackHandler = (0, react_1.useCallback)(() => {
        if (dispatch) {
            dispatch({ type: actions_1.QuestionTypes.Back });
        }
    }, [dispatch]);
    const contextValue = {
        dispatch,
        questionResponse,
        state,
        resultsResponse,
        isFirstQuestion,
        quizNextHandler,
        quizBackHandler,
        cioClient,
    };
    (0, react_1.useEffect)(() => {
        (() => tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (cioClient) {
                setRequestState(constants_1.RequestStates.Loading);
                if (state.isLastAnswer) {
                    try {
                        const quizResults = yield (0, utils_1.getQuizResults)(cioClient, quizId, {
                            answers: state.answers,
                            resultsPerPage: resultsPageOptions === null || resultsPageOptions === void 0 ? void 0 : resultsPageOptions.numResultsToDisplay,
                            quizVersionId,
                            quizSessionId,
                        });
                        setResultsResponse(quizResults);
                        setRequestState(constants_1.RequestStates.Success);
                        setQuestionResponse(undefined);
                    }
                    catch (error) {
                        setResultsResponse(undefined);
                        setRequestState(constants_1.RequestStates.Error);
                    }
                }
                else {
                    try {
                        const questionResult = yield (0, utils_1.getNextQuestion)(cioClient, quizId, {
                            answers: state.answers,
                            quizVersionId,
                            quizSessionId,
                        });
                        setQuestionResponse(questionResult);
                        setRequestState(constants_1.RequestStates.Success);
                        setResultsResponse(undefined);
                        if (!quizVersionId && (questionResult === null || questionResult === void 0 ? void 0 : questionResult.quiz_version_id)) {
                            setQuizVersionId(questionResult.quiz_version_id);
                        }
                        if (!quizSessionId && (questionResult === null || questionResult === void 0 ? void 0 : questionResult.quiz_session_id)) {
                            setQuizSessionId(questionResult.quiz_session_id);
                        }
                    }
                    catch (error) {
                        setRequestState(constants_1.RequestStates.Error);
                    }
                }
            }
        }))();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [cioClient, state, quizId, state.isLastAnswer, resultsPageOptions === null || resultsPageOptions === void 0 ? void 0 : resultsPageOptions.numResultsToDisplay]);
    (0, react_1.useEffect)(() => {
        if (!firstQuestion) {
            setFirstQuestion(questionResponse);
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [questionResponse]);
    const resetQuizSessionId = () => {
        setQuizSessionId('');
    };
    if (requestState === constants_1.RequestStates.Loading) {
        return (react_1.default.createElement("div", { className: 'cio-quiz' },
            react_1.default.createElement(Spinner_1.default, null)));
    }
    if (requestState === constants_1.RequestStates.Success) {
        return (react_1.default.createElement("div", { className: 'cio-quiz' },
            react_1.default.createElement(context_1.default.Provider, { value: contextValue },
                resultsResponse && (react_1.default.createElement(ResultContainer_1.default, { options: resultsPageOptions, resetQuizSessionId: resetQuizSessionId })),
                questionResponse && react_1.default.createElement(QuizQuestions_1.default, { questionResponse: questionResponse }))));
    }
    return null;
}
exports.default = CioQuiz;
