"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const QuestionTitle_1 = tslib_1.__importDefault(require("../QuestionTitle/QuestionTitle"));
const QuestionDescription_1 = tslib_1.__importDefault(require("../QuestionDescription/QuestionDescription"));
const context_1 = tslib_1.__importDefault(require("../CioQuiz/context"));
const utils_1 = require("../../utils");
const actions_1 = require("../CioQuiz/actions");
const ControlBar_1 = tslib_1.__importDefault(require("../ControlBar/ControlBar"));
function SelectTypeQuestion() {
    var _a;
    const { questionResponse, state, quizNextHandler, quizBackHandler, isFirstQuestion } = (0, react_1.useContext)(context_1.default);
    let question;
    let type;
    let hasImages = false;
    if (questionResponse) {
        question = questionResponse.next_question;
        type = question.type;
        hasImages = questionResponse.next_question.options.some((option) => option.images);
    }
    const [selected, setSelected] = (0, react_1.useState)({});
    const isDisabled = Object.keys(selected).length === 0;
    (0, react_1.useEffect)(() => {
        var _a, _b;
        if ((_a = questionResponse === null || questionResponse === void 0 ? void 0 : questionResponse.next_question) === null || _a === void 0 ? void 0 : _a.type) {
            const answers = ((_b = state === null || state === void 0 ? void 0 : state.answerInputs) === null || _b === void 0 ? void 0 : _b[questionResponse.next_question.id]) || [];
            const prevSelected = {};
            answers === null || answers === void 0 ? void 0 : answers.forEach((answer) => {
                prevSelected[Number(answer)] = true;
            });
            setSelected(prevSelected);
        }
    }, [questionResponse, state === null || state === void 0 ? void 0 : state.answerInputs]);
    const toggleIdSelected = (id) => {
        if (type === actions_1.QuestionTypes.SingleSelect) {
            setSelected({ [id]: true });
        }
        else if (type === actions_1.QuestionTypes.MultipleSelect) {
            if (selected[id]) {
                const newState = Object.assign({}, selected);
                delete newState[id];
                setSelected(newState);
            }
            else {
                setSelected(Object.assign(Object.assign({}, selected), { [id]: true }));
            }
        }
    };
    const onOptionKeyDown = (event, id) => {
        if ((event === null || event === void 0 ? void 0 : event.key) === ' ' || (event === null || event === void 0 ? void 0 : event.key) === 'Enter') {
            toggleIdSelected(id);
        }
    };
    const onNextClick = () => {
        if (quizNextHandler && !isDisabled && questionResponse) {
            const questionType = type === actions_1.QuestionTypes.SingleSelect
                ? actions_1.QuestionTypes.SingleSelect
                : actions_1.QuestionTypes.MultipleSelect;
            quizNextHandler({
                type: questionType,
                payload: {
                    questionId: questionResponse === null || questionResponse === void 0 ? void 0 : questionResponse.next_question.id,
                    input: Object.keys(selected).filter((key) => selected[Number(key)]),
                    isLastQuestion: questionResponse.is_last_question,
                },
            });
        }
    };
    if (question) {
        return (react_1.default.createElement("div", { className: 'cio-select-question-container' },
            react_1.default.createElement("div", { className: 'cio-select-question-text' },
                react_1.default.createElement(QuestionTitle_1.default, { title: question.title }),
                (question === null || question === void 0 ? void 0 : question.description) ? react_1.default.createElement(QuestionDescription_1.default, { description: question.description }) : ''),
            react_1.default.createElement("div", { className: `${!hasImages
                    ? 'cio-question-options-container-text-only'
                    : 'cio-question-options-container'}` }, (_a = question === null || question === void 0 ? void 0 : question.options) === null || _a === void 0 ? void 0 : _a.map((option) => (react_1.default.createElement("div", { className: `${!hasImages
                    ? 'cio-question-option-container-text-only'
                    : 'cio-question-option-container'} ${selected[option.id] ? 'selected' : ''}`, onClick: () => {
                    toggleIdSelected(option.id);
                }, onKeyDown: (event) => {
                    onOptionKeyDown(event, option.id);
                }, role: 'button', tabIndex: 0, key: option.id },
                option.images ? (0, utils_1.renderImages)(option.images, 'cio-question-option-image') : '',
                react_1.default.createElement("div", { className: 'cio-question-option-value' }, option === null || option === void 0 ? void 0 : option.value))))),
            react_1.default.createElement(ControlBar_1.default, { nextButtonHandler: onNextClick, isNextButtonDisabled: isDisabled, backButtonHandler: quizBackHandler, showBackButton: !isFirstQuestion, ctaButtonText: question === null || question === void 0 ? void 0 : question.cta_text })));
    }
    return null;
}
exports.default = SelectTypeQuestion;
