"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPreferredColorScheme = exports.getCioClient = exports.getQuestionTypes = exports.getQuizResults = exports.getNextQuestion = exports.stringify = exports.stringifyWithDefaults = exports.defaultAddToCartCallbackCode = exports.getStoryParams = exports.renderImages = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importDefault(require("react"));
const constructorio_client_javascript_1 = tslib_1.__importDefault(require("@constructor-io/constructorio-client-javascript"));
const actions_1 = require("./components/CioQuiz/actions");
const renderImages = (images, cssClasses) => {
    const { primary_url: primaryUrl, primary_alt: primaryAlt, secondary_url: secondaryUrl, secondary_alt: secondaryAlt, } = images;
    if (primaryUrl) {
        const windowWidth = window.innerWidth;
        let src = primaryUrl;
        let alt = primaryAlt || 'Quiz Image';
        if (windowWidth > 768 && secondaryUrl) {
            src = secondaryUrl;
            if (secondaryAlt) {
                alt = secondaryAlt;
            }
        }
        return (react_1.default.createElement("span", { className: `${cssClasses || ''}`.trim() },
            react_1.default.createElement("img", { className: 'cio-question-image', src: src, alt: alt })));
    }
    return '';
};
exports.renderImages = renderImages;
// More on Story layout: https://storybook.js.org/docs/react/configure/story-layout
const getStoryParams = (storyCode, templateCode, importCode) => {
    const code = `
${importCode}
${storyCode}
${templateCode}
`;
    return {
        docs: {
            source: {
                code,
                language: 'jsx',
                format: true,
                type: 'code',
            },
        },
    };
};
exports.getStoryParams = getStoryParams;
exports.defaultAddToCartCallbackCode = `"addToCartCallback": (item) => console.dir(item)`;
const stringifyWithDefaults = (obj) => {
    const { addToCartCallback, cioJsClient } = obj, rest = tslib_1.__rest(obj, ["addToCartCallback", "cioJsClient"]);
    let res = JSON.stringify(rest, null, '  ');
    if (cioJsClient) {
        res = res.replace('"resultsPageOptions": {', `"cioJsClient": cioJsClient,
  "resultsPageOptions": {`);
    }
    res = res.replace('"resultsPageOptions": {', `"resultsPageOptions": {
    ${exports.defaultAddToCartCallbackCode},`);
    return res;
};
exports.stringifyWithDefaults = stringifyWithDefaults;
const stringify = (obj) => JSON.stringify(obj, null, '  ');
exports.stringify = stringify;
const getNextQuestion = (cioClient, quizId, parameters) => cioClient === null || cioClient === void 0 ? void 0 : cioClient.quizzes.getQuizNextQuestion(quizId, parameters);
exports.getNextQuestion = getNextQuestion;
const getQuizResults = (cioClient, quizId, parameters) => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return cioClient === null || cioClient === void 0 ? void 0 : cioClient.quizzes.getQuizResults(quizId, parameters); });
exports.getQuizResults = getQuizResults;
const getQuestionTypes = (questionType) => {
    const isOpenQuestion = questionType === actions_1.QuestionTypes.OpenText;
    const isCoverQuestion = questionType === actions_1.QuestionTypes.Cover;
    const isSingleQuestion = questionType === actions_1.QuestionTypes.SingleSelect;
    const isMultipleQuestion = questionType === actions_1.QuestionTypes.MultipleSelect;
    const isSelectQuestion = isSingleQuestion || isMultipleQuestion;
    return {
        isOpenQuestion,
        isCoverQuestion,
        isSingleQuestion,
        isMultipleQuestion,
        isSelectQuestion,
    };
};
exports.getQuestionTypes = getQuestionTypes;
const getCioClient = (apiKey) => {
    if (apiKey) {
        return new constructorio_client_javascript_1.default({
            apiKey,
            sendTrackingEvents: true,
        });
    }
    return undefined;
};
exports.getCioClient = getCioClient;
function getPreferredColorScheme() {
    var _a;
    let colorScheme = 'light';
    // Check if the dark-mode Media-Query matches
    if ((_a = window.matchMedia('(prefers-color-scheme: dark)')) === null || _a === void 0 ? void 0 : _a.matches) {
        colorScheme = 'dark';
    }
    return colorScheme;
}
exports.getPreferredColorScheme = getPreferredColorScheme;
