import React, { useEffect, useState, useContext } from 'react';
import QuestionTitle from '../QuestionTitle/QuestionTitle';
import QuestionDescription from '../QuestionDescription/QuestionDescription';
import QuizContext from '../CioQuiz/context';
import { renderImages } from '../../utils';
import { QuestionTypes } from '../CioQuiz/actions';
import ControlBar from '../ControlBar/ControlBar';
function SelectTypeQuestion() {
    const { questionResponse, state, quizNextHandler, quizBackHandler, isFirstQuestion } = useContext(QuizContext);
    let question;
    let type;
    let hasImages = false;
    if (questionResponse) {
        question = questionResponse.next_question;
        type = question.type;
        hasImages = questionResponse.next_question.options.some((option) => option.images);
    }
    const [selected, setSelected] = useState({});
    const isDisabled = Object.keys(selected).length === 0;
    useEffect(() => {
        if (questionResponse?.next_question?.type) {
            const answers = state?.answerInputs?.[questionResponse.next_question.id] || [];
            const prevSelected = {};
            answers?.forEach((answer) => {
                prevSelected[Number(answer)] = true;
            });
            setSelected(prevSelected);
        }
    }, [questionResponse, state?.answerInputs]);
    const toggleIdSelected = (id) => {
        if (type === QuestionTypes.SingleSelect) {
            setSelected({ [id]: true });
        }
        else if (type === QuestionTypes.MultipleSelect) {
            if (selected[id]) {
                const newState = { ...selected };
                delete newState[id];
                setSelected(newState);
            }
            else {
                setSelected({ ...selected, [id]: true });
            }
        }
    };
    const onOptionKeyDown = (event, id) => {
        if (event?.key === ' ' || event?.key === 'Enter') {
            toggleIdSelected(id);
        }
    };
    const onNextClick = () => {
        if (quizNextHandler && !isDisabled && questionResponse) {
            const questionType = type === QuestionTypes.SingleSelect
                ? QuestionTypes.SingleSelect
                : QuestionTypes.MultipleSelect;
            quizNextHandler({
                type: questionType,
                payload: {
                    questionId: questionResponse?.next_question.id,
                    input: Object.keys(selected).filter((key) => selected[Number(key)]),
                    isLastQuestion: questionResponse.is_last_question,
                },
            });
        }
    };
    if (question) {
        return (React.createElement("div", { className: 'cio-select-question-container' },
            React.createElement("div", { className: 'cio-select-question-text' },
                React.createElement(QuestionTitle, { title: question.title }),
                question?.description ? React.createElement(QuestionDescription, { description: question.description }) : ''),
            React.createElement("div", { className: `${!hasImages
                    ? 'cio-question-options-container-text-only'
                    : 'cio-question-options-container'}` }, question?.options?.map((option) => (React.createElement("div", { className: `${!hasImages
                    ? 'cio-question-option-container-text-only'
                    : 'cio-question-option-container'} ${selected[option.id] ? 'selected' : ''}`, onClick: () => {
                    toggleIdSelected(option.id);
                }, onKeyDown: (event) => {
                    onOptionKeyDown(event, option.id);
                }, role: 'button', tabIndex: 0, key: option.id },
                option.images ? renderImages(option.images, 'cio-question-option-image') : '',
                React.createElement("div", { className: 'cio-question-option-value' }, option?.value))))),
            React.createElement(ControlBar, { nextButtonHandler: onNextClick, isNextButtonDisabled: isDisabled, backButtonHandler: quizBackHandler, showBackButton: !isFirstQuestion, ctaButtonText: question?.cta_text })));
    }
    return null;
}
export default SelectTypeQuestion;
