import React from 'react';
import ConstructorIOClient from '@constructor-io/constructorio-client-javascript';
import { QuestionTypes } from './components/CioQuiz/actions';
export const renderImages = (images, cssClasses) => {
    const { primary_url: primaryUrl, primary_alt: primaryAlt, secondary_url: secondaryUrl, secondary_alt: secondaryAlt, } = images;
    if (primaryUrl) {
        const windowWidth = window.innerWidth;
        let src = primaryUrl;
        let alt = primaryAlt || 'Quiz Image';
        if (windowWidth > 768 && secondaryUrl) {
            src = secondaryUrl;
            if (secondaryAlt) {
                alt = secondaryAlt;
            }
        }
        return (React.createElement("span", { className: `${cssClasses || ''}`.trim() },
            React.createElement("img", { className: 'cio-question-image', src: src, alt: alt })));
    }
    return '';
};
// More on Story layout: https://storybook.js.org/docs/react/configure/story-layout
export const getStoryParams = (storyCode, templateCode, importCode) => {
    const code = `
${importCode}
${storyCode}
${templateCode}
`;
    return {
        docs: {
            source: {
                code,
                language: 'jsx',
                format: true,
                type: 'code',
            },
        },
    };
};
export const defaultAddToCartCallbackCode = `"addToCartCallback": (item) => console.dir(item)`;
export const stringifyWithDefaults = (obj) => {
    const { addToCartCallback, cioJsClient, ...rest } = obj;
    let res = JSON.stringify(rest, null, '  ');
    if (cioJsClient) {
        res = res.replace('"resultsPageOptions": {', `"cioJsClient": cioJsClient,
  "resultsPageOptions": {`);
    }
    res = res.replace('"resultsPageOptions": {', `"resultsPageOptions": {
    ${defaultAddToCartCallbackCode},`);
    return res;
};
export const stringify = (obj) => JSON.stringify(obj, null, '  ');
export const getNextQuestion = (cioClient, quizId, parameters) => cioClient?.quizzes.getQuizNextQuestion(quizId, parameters);
export const getQuizResults = async (cioClient, quizId, parameters) => cioClient?.quizzes.getQuizResults(quizId, parameters);
export const getQuestionTypes = (questionType) => {
    const isOpenQuestion = questionType === QuestionTypes.OpenText;
    const isCoverQuestion = questionType === QuestionTypes.Cover;
    const isSingleQuestion = questionType === QuestionTypes.SingleSelect;
    const isMultipleQuestion = questionType === QuestionTypes.MultipleSelect;
    const isSelectQuestion = isSingleQuestion || isMultipleQuestion;
    return {
        isOpenQuestion,
        isCoverQuestion,
        isSingleQuestion,
        isMultipleQuestion,
        isSelectQuestion,
    };
};
export const getCioClient = (apiKey) => {
    if (apiKey) {
        return new ConstructorIOClient({
            apiKey,
            sendTrackingEvents: true,
        });
    }
    return undefined;
};
export function getPreferredColorScheme() {
    let colorScheme = 'light';
    // Check if the dark-mode Media-Query matches
    if (window.matchMedia('(prefers-color-scheme: dark)')?.matches) {
        colorScheme = 'dark';
    }
    return colorScheme;
}
